# OPTIONS

-h, --help
:   Show a help message and exit.

-v, --version
:   Show program version number and exit.

-c *CONFIG*, --config *CONFIG*
:   Use the specified configuration file.

--color *{never,always,auto}*, --colour *{never,always,auto}*
:   Whether to use colors in the output (default: *auto*)

-q, --quiet
:   Do not output anything. Useful for cron scripts.

-d, --debug
:   debug output (default: False)

--log-level {NOTSET,DEBUG,INFO,WARNING,ERROR,CRITICAL}
:   Override the default log level


-f {json,console}, --format {json,console}
:   output format (default: 'console')
